#include "alg/sequence_location.hpp"

#include <cstdlib>
    
SequenceLocation::SequenceLocation(
    const boost::shared_ptr<Sequence> s, 
    int l, 
    int r
) : sequence(s), 
    left(l), 
    right(r)
{
}

SequenceLocation::SequenceLocation(
    const Sequence& s, 
    int l, 
    int r
) : left(l), 
    right(r)
{
  boost::shared_ptr<Sequence> copy(new Sequence(s));
  sequence = copy;
}


SequenceLocation::SequenceLocation(const SequenceLocation& o) 
  : sequence(o.sequence),
    left(o.left),
    right(o.right)
{
}

SequenceLocation& SequenceLocation::operator=(const SequenceLocation& o)
{
  if (this != &o) {
    sequence = o.sequence;
    left = o.getLeft();
    right = o.getRight();
  }
  return *this;
}


const Sequence& SequenceLocation::getSequence() const
{
  return *sequence;
}

Sequence SequenceLocation::getSelectedSequence() const
{
  return sequence->subseq(getLeft(), getCount());
}

void SequenceLocation::setLeft(int l)
{
  left = l;
}

int SequenceLocation::getLeft() const
{
  return left;
}

void SequenceLocation::setCount(SequenceLocation::size_type c)
{
  right = left + c;
}

SequenceLocation::size_type SequenceLocation::getCount() const
{
  return std::max(right - left, 0);
}

void SequenceLocation::setRight(int r)
{
  right = r;
}

int SequenceLocation::getRight() const
{
  return right;
}

SequenceLocation::size_type SequenceLocation::size() const
{
  return getCount();
}
