#define BOOST_AUTO_TEST_MAIN
#include <boost/test/auto_unit_test.hpp>

#include "seq.hpp"

BOOST_AUTO_TEST_CASE( seqstring_default_alphabet )
{
  SeqString s;
  BOOST_CHECK_EQUAL(s.get_alphabet_ref(), reduced_nucleic_alphabet);
  BOOST_CHECK_EQUAL(s.get_alphabet(), Alphabet::reduced_nucleic_alphabet());
  BOOST_CHECK_EQUAL(s.size(), 0);
}

BOOST_AUTO_TEST_CASE( seqstring_string )
{
  SeqString s("AGCT");

  BOOST_CHECK_EQUAL(s.get_alphabet_ref(), reduced_nucleic_alphabet);
  BOOST_CHECK_EQUAL(s.get_alphabet(), Alphabet::reduced_nucleic_alphabet());
  BOOST_CHECK_EQUAL(s.size(), 4);  
}

// such an exciting unit test, making sure that a=b; a==b
BOOST_AUTO_TEST_CASE( seqstring_string_nucleic_alphabet )
{
  SeqString s("AGCT", nucleic_alphabet);

  BOOST_CHECK_EQUAL(s.get_alphabet_ref(), nucleic_alphabet);
  BOOST_CHECK_EQUAL(s.get_alphabet(), Alphabet::nucleic_alphabet());
  BOOST_CHECK_EQUAL(s.size(), 4);  
}

// such an exciting unit test, making sure that a=b; a==b
BOOST_AUTO_TEST_CASE( seqstring_string_dna_alphabet )
{
  SeqString s("AGCT", dna_alphabet);

  BOOST_CHECK_EQUAL(s.get_alphabet_ref(), dna_alphabet);
  BOOST_CHECK_EQUAL(s.get_alphabet(), Alphabet::dna_alphabet());
  BOOST_CHECK_EQUAL(s.size(), 4);  
}